@@ -452,6 +452,16 @@ func showNeighbor(args []string) error {
 					fmt.Printf("         %s:\t%s\n", item.RouteFamily, item.Mode)
 				}
 			}
+		case bgp.BGP_CAP_FQDN:
+			fmt.Printf("    %s:\t%s\n", c.Code(), support)
+			if m := lookup(c, lcaps); m != nil {
+				fmt.Println("      Local:")
+				fmt.Printf("         name: %s, domain: %s\n", m.(*bgp.CapFQDN).HostName, m.(*bgp.CapFQDN).DomainName)
+			}
+			if m := lookup(c, rcaps); m != nil {
+				fmt.Println("      Remote:")
+				fmt.Printf("         name: %s, domain: %s\n", m.(*bgp.CapFQDN).HostName, m.(*bgp.CapFQDN).DomainName)
+			}
 		default:
 			fmt.Printf("    %s:\t%s\n", c.Code(), support)
 		}
@@ -1213,8 +1223,10 @@ func modNeighbor(cmdType string, args []string) error {
 		switch cmdType {
 		case cmdAdd, cmdDel:
 			peer = &api.Peer{
-				Conf:  &api.PeerConf{},
-				State: &api.PeerState{},
+				Conf:           &api.PeerConf{},
+				State:          &api.PeerState{},
+				RouteServer:    &api.RouteServer{},
+				RouteReflector: &api.RouteReflector{},
 			}
 			if unnumbered {
 				peer.Conf.NeighborInterface = m["interface"][0]
